@@ -44,6 +44,7 @@ int Detail(char *dev, int brief)
 	int d;
 	time_t atime;
 	char *c;
+	char *devices = NULL;
 
 	mdp_super_t super;
 	int have_super = 0;
@@ -79,14 +80,20 @@ int Detail(char *dev, int brief)
 	/* Ok, we have some info to print... */
 	c = map_num(pers, array.level);
 	if (brief) 
-		printf("ARRAY %s level=%s disks=%d", dev, c?c:"-unknown-",array.raid_disks );
+		printf("ARRAY %s level=%s num-devices=%d", dev, c?c:"-unknown-",array.raid_disks );
 	else {
-		long array_size;
-		long long larray_size;
+		unsigned long array_size;
+		unsigned long long larray_size;
+#ifdef BLKGETSIZE64
 		if (ioctl(fd, BLKGETSIZE64, &larray_size)==0)
 			;
-		else if (ioctl(fd, BLKGETSIZE, &array_size)==0)
-			larray_size = array_size<<9;
+		else
+#endif
+			if (ioctl(fd, BLKGETSIZE, &array_size)==0) {
+				larray_size = array_size;
+				larray_size <<= 9;
+			}
+		
 		else larray_size = 0;
 
 		printf("%s:\n", dev);
@@ -96,13 +103,13 @@ int Detail(char *dev, int brief)
 		printf("  Creation Time : %.24s\n", ctime(&atime));
 		printf("     Raid Level : %s\n", c?c:"-unknown-");
 		if (larray_size)
-		printf("     Array Size : %ld%s\n", (long)(larray_size>>10), human_size(larray_size));
+		printf("     Array Size : %llu%s\n", (larray_size>>10), human_size(larray_size));
 		if (array.level >= 1)
 			printf("    Device Size : %d%s\n", array.size, human_size((long long)array.size<<10));
-		printf("     Raid Disks : %d\n", array.raid_disks);
-		printf("    Total Disks : %d\n", array.nr_disks);
+		printf("   Raid Devices : %d\n", array.raid_disks);
+		printf("  Total Devices : %d\n", array.nr_disks);
 		printf("Preferred Minor : %d\n", array.md_minor);
-		printf("    Persistance : Superblock is %spersistant\n",
+		printf("    Persistence : Superblock is %spersistent\n",
 		       array.not_persistent?"not ":"");
 		printf("\n");
 		atime = array.utime;
@@ -110,10 +117,10 @@ int Detail(char *dev, int brief)
 		printf("          State : %s, %serrors\n",
 		       (array.state&(1<<MD_SB_CLEAN))?"clean":"dirty",
 		       (array.state&(1<<MD_SB_ERRORS))?"":"no-");
-		printf("  Active Drives : %d\n", array.active_disks);
-		printf(" Working Drives : %d\n", array.working_disks);
-		printf("  Failed Drives : %d\n", array.failed_disks);
-		printf("   Spare Drives : %d\n", array.spare_disks);
+		printf(" Active Devices : %d\n", array.active_disks);
+		printf("Working Devices : %d\n", array.working_disks);
+		printf(" Failed Devices : %d\n", array.failed_disks);
+		printf("  Spare Devices : %d\n", array.spare_disks);
 		printf("\n");
 		if (array.level == 5) {
 			c = map_num(r5layout, array.layout);
@@ -132,17 +139,22 @@ int Detail(char *dev, int brief)
 		}
 	
 		printf("\n");
-		printf("    Number   Major   Minor   RaidDisk   State\n");
+		printf("    Number   Major   Minor   RaidDevice State\n");
 	}
-	for (d= 0; d<array.raid_disks+array.spare_disks; d++) {
+	for (d= 0; d<MD_SB_DISKS; d++) {
 		mdu_disk_info_t disk;
 		char *dv;
 		disk.number = d;
 		if (ioctl(fd, GET_DISK_INFO, &disk) < 0) {
-			fprintf(stderr, Name ": cannot get disk detail for disk %d: %s\n",
-				d, strerror(errno));
+			if (d < array.raid_disks)
+				fprintf(stderr, Name ": cannot get device detail for device %d: %s\n",
+					d, strerror(errno));
 			continue;
 		}
+		if (d >= array.raid_disks &&
+		    disk.major == 0 &&
+		    disk.minor == 0)
+			continue;
 		if (!brief) {
 			printf("   %5d   %5d    %5d    %5d     ", 
 			       disk.number, disk.major, disk.minor, disk.raid_disk);
@@ -152,8 +164,16 @@ int Detail(char *dev, int brief)
 			if (disk.state & (1<<MD_DISK_REMOVED)) printf(" removed");
 		}
 		if ((dv=map_dev(disk.major, disk.minor))) {
-			if (!brief) printf("   %s", dv);
-			if (!have_super) {
+			if (brief) {
+				if (devices) {
+					devices = realloc(devices,
+							  strlen(devices)+1+strlen(dv)+1);
+					strcat(strcat(devices,","),dv);
+				} else
+					devices = strdup(dv);
+			} else
+				printf("   %s", dv);
+			if (!have_super && (disk.state & (1<<MD_DISK_ACTIVE))) {
 				/* try to read the superblock from this device
 				 * to get more info
 				 */
@@ -175,8 +195,10 @@ int Detail(char *dev, int brief)
 			       super.set_uuid2, super.set_uuid3);
 		else
 			printf("%08x", super.set_uuid0);
-		if (!brief) printf("\n");
+		if (!brief) 
+			printf("\n         Events : %d.%d\n", super.events_hi, super.events_lo);
 	}
+	if (brief && devices) printf("\n   devices=%s", devices);
 	if (brief) printf("\n");
 	return 0;
 }
