@@ -129,7 +129,7 @@ int Manage_subdevs(char *devname, int fd,
 	mdu_disk_info_t disc;
 	mddev_dev_t dv;
 	struct stat stb;
-	int i,j;
+	int j;
 	int save_errno;
 	static char buf[4096];
 
@@ -151,8 +151,8 @@ int Manage_subdevs(char *devname, int fd,
 		}
 		switch(dv->disposition){
 		default:
-			fprintf(stderr, Name ": internal error - devmode[%d]=%d\n",
-				i, dv->disposition);
+			fprintf(stderr, Name ": internal error - devmode[%s]=%d\n",
+				dv->devname, dv->disposition);
 			return 1;
 		case 'a':
 			/* add the device - hot or cold */
@@ -190,7 +190,7 @@ int Manage_subdevs(char *devname, int fd,
 			disc.major = MAJOR(stb.st_rdev);
 			disc.minor = MINOR(stb.st_rdev);
 			if (ioctl(fd,ADD_NEW_DISK, &disc)) {
-				fprintf(stderr, Name ": add new disk failed for %s: %s\n",
+				fprintf(stderr, Name ": add new device failed for %s: %s\n",
 					dv->devname, strerror(errno));
 				return 1;
 			}
@@ -211,7 +211,7 @@ int Manage_subdevs(char *devname, int fd,
 		case 'f': /* set faulty */
 			/* FIXME check current member */
 			if (ioctl(fd, SET_DISK_FAULTY, (unsigned long) stb.st_rdev)) {
-				fprintf(stderr, Name ": set disk faulty failed for %s:  %s\n",
+				fprintf(stderr, Name ": set device faulty failed for %s:  %s\n",
 					dv->devname, strerror(errno));
 				return 1;
 			}
