@@ -69,7 +69,7 @@ enum mode {
 
 extern char short_options[];
 extern struct option long_options[];
-extern char Version[], Usage[], Help[],
+extern char Version[], Usage[], Help[], OptionHelp[],
 	Help_create[], Help_build[], Help_assemble[],
 	Help_manage[], Help_misc[], Help_monitor[], Help_config[];
 
@@ -150,6 +150,7 @@ extern int Assemble(char *mddev, int mdfd,
 		    char *conffile,
 		    mddev_dev_t devlist,
 		    int readonly, int runstop,
+		    char *update,
 		    int verbose, int force);
 
 extern int Build(char *mddev, int mdfd, int chunk, int level,
@@ -164,10 +165,10 @@ extern int Create(char *mddev, int mdfd,
 
 extern int Detail(char *dev, int brief);
 extern int Query(char *dev);
-extern int Examine(mddev_dev_t devlist, int brief, int scan);
+extern int Examine(mddev_dev_t devlist, int brief, int scan, int SparcAdjust);
 extern int Monitor(mddev_dev_t devlist,
 		   char *mailaddr, char *alert_cmd,
-		   int period, int scan,
+		   int period, int daemonise, int scan,
 		   char *config);
 
 extern int Kill(char *dev, int force);
